<?php

namespace Drupal\carryquery\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure the query carry forward keys and related information.
 */
class QredirectConfig extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['carryquery.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'carryquery';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('carryquery.settings');

    $form['carryqueryconfig'] = [
      '#title' => $this->t('Query carry forward configuration'),
      '#type' => 'textarea',
      '#default_value' => !empty($config->get('carryqueryconfig')) ? $config->get('carryqueryconfig') : '',
      '#description' => $this->t(
          'Add the URL query parameter key here to carray forward them to next page.Example: URL contians path /path1?data=value you want to carry data=value to any of the next page then place the "data" key in the field. Multiple key must be seperated by newline'
      ),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('carryquery.settings');

    $data = $form_state->getValue('carryqueryconfig');
    $dataLines = preg_split("/\\r\\n|\\r|\\n/", $data);
    $queryInfo = [];
    $queryKeys = [];
    foreach ($dataLines as $value) {
      $arrPipeSplit = explode('|', $value);
      $queryInfo[$arrPipeSplit[0]] = $arrPipeSplit;
      $queryKeys[] = $arrPipeSplit[0];
    }

    $config->set('carryqueryconfig', $form_state->getValue('carryqueryconfig'))
      ->set('keys', $queryKeys)
      ->set('info', $queryInfo)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
